<!-- ---
hide:
- navigation
--- -->

# Examples

Welcome to the **Examples** section of our documentation! 🎉

The COOM Suite contains a range of (product) configuration examples encoded in
the [COOM language][coom]. They can be found in the [Examples folder][examples-coom].

For illustration of the different COOM language fragments,
we have various examples of bike configurations in increasing complexity:

- [Kids Bike][kids]
- [City Bike][city]
- [Travel Bike][travel]
- [Cargo Bike][cargo]

We obtain the corresponding ASP facts to these examples, see the *Convert COOM to ASP* paragraph in [Usage][usage].
More background information on how they are obtained can be found in the [Translation][translation] section.


## How to Use This Section

Each example includes:

1. **Instructions** to run the example.
1. **Code snippets** to demonstrate implementation.
1. **Helpful visuals** to illustrate key concepts.

Dive in and start exploring!

[coom]: ../reference/coom/index.md
[examples-coom]: https://github.com/potassco/coom-suite/tree/master/examples/coom/
[examples-asp]: https://github.com/potassco/coom-suite/tree/master/examples/asp/
[usage]: ../usage/index.md
[translation]: ../reference/translation/index.md
[kids]: kids-bike.md
[city]: city-bike.md
[travel]: travel-bike.md
[cargo]: cargo-bike.md
